"""
MACAO Experiments Module

Provides experiment execution and management utilities.
"""

from .experiment_runner import ExperimentRunner, ExperimentResult

__all__ = ['ExperimentRunner', 'ExperimentResult']

